Learn R Programming

delma (version 0.1.2)

as_eml_list: Convert metadata to a list

Description

Takes an object of class xml_document or tibble, and converts it to a list. When converting from an xml_document, this is simply a wrapper for xml2::as_list()

Usage

as_eml_list(x, ...)

# S3 method for tbl_lp as_eml_list(x, ...)

# S3 method for tbl_df as_eml_list(x, ...)

# S3 method for list as_eml_list(x, ...)

# S3 method for xml_document as_eml_list(x, ...)

Value

A list, where both the nested structure of the XML/md and the attributes of XML nodes, are preserved.

Arguments

x

Object to be converted

...

Other arguments, currently ignored

Examples

Run this code
source_file <- system.file("extdata", 
                           "bionet_metadata.Rmd",
                           package = "delma")
df <- read_md(source_file)
as_eml_list(df) |> str()

Run the code above in your browser using DataLab