Learn R Programming

delma (version 0.1.2)

as_eml_tibble: Convert metadata to a tibble

Description

Takes objects of class list or xml_document and converts them to a tibble with a particular structure, designed for storing nested data. Tibbles are required because attributes are stored as list-columns, which are not supported by class data.frame.

Usage

as_eml_tibble(x, ...)

# S3 method for tbl_df as_eml_tibble(x, ...)

# S3 method for tbl_lp as_eml_tibble(x, ...)

# S3 method for list as_eml_tibble(x, ...)

# S3 method for xml_document as_eml_tibble(x, ...)

Value

An object of class tbl_df, tbl and data.frame, containing the following fields:

  • level (int) gives the nestedness level of the node/heading in question

  • label (chr) the xml tag

  • text (chr) Any text stored within that tag

  • attributes (list) Any attributes for that tag

Arguments

x

Object to be converted

...

Other arguments, currently ignored

Examples

Run this code
source_file <- system.file("extdata", 
                           "bionet_metadata.xml",
                           package = "delma")
xml_data <- xml2::read_xml(source_file)
as_eml_tibble(xml_data)

Run the code above in your browser using DataLab