Takes objects of class list or xml_document and converts
them to a tibble with a particular structure, designed for storing nested
data. Tibbles are required because attributes are stored as list-columns,
which are not supported by class data.frame.
Usage
as_eml_tibble(x, ...)
# S3 method for tbl_df
as_eml_tibble(x, ...)
# S3 method for tbl_lp
as_eml_tibble(x, ...)
# S3 method for list
as_eml_tibble(x, ...)
# S3 method for xml_document
as_eml_tibble(x, ...)
Value
An object of class tbl_df, tbl and data.frame, containing
the following fields:
level (int) gives the nestedness level of the node/heading in question