Takes a character vector, tibble, or list and converts it to an
xml_document, as defined by the xml2 package. When converting from
a list, this is simply a wrapper for xml2::as_xml_document().
Usage
as_eml_xml(x, ...)
# S3 method for tbl_lp
as_eml_xml(x, ...)
# S3 method for tbl_df
as_eml_xml(x, ...)
# S3 method for list
as_eml_xml(x, ...)
# S3 method for xml_document
as_eml_xml(x, ...)
Value
An xml_document with the specified nodes and attributes.