as_lp_tibble: Convert metadata to a lightparser tibble
Description
Takes objects of class tbl_df, list or xml_document and converts
them to a tibble with a structure required by lightparser. Note that
delma represents these as an object of class tbl_lp for convenience.
Usage
as_lp_tibble(x, ...)
# S3 method for tbl_lp
as_lp_tibble(x, ...)
# S3 method for tbl_df
as_lp_tibble(x, ...)
# S3 method for list
as_lp_tibble(x, ...)
# S3 method for xml_document
as_lp_tibble(x, ...)
Value
An object of class tbl_lp, tbl_df, tbl and data.frame, containing
the following fields:
type (chr) Whether that section is e.g. YAML, inline text, heading, or code block
label (chr) The tag associated with a given code block (otherwise NA)
params (list) Attributes of a code block
text (list) Any text in that section
code (list) Any code in that section
heading (chr) For type = heading, the value of that heading
heading_level (dbl) The heading level of that heading (i.e. number of #)
section (chr) The heading this section sits within